@@ -36,8 +36,7 @@ GrantleeKi18nLocalizer::~GrantleeKi18nLocalizer()
 {
 }
 
-QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr,
-        const QVariantList &arguments) const
+QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, const QVariantList &arguments) const
 {
     KLocalizedString str = kstr;
     for (auto iter = arguments.cbegin(), end = arguments.cend(); iter != end; ++iter) {
@@ -68,7 +67,10 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr,
                 str = str.subs(iter->value<Grantlee::SafeString>().get());
                 break;
             }
-        // fall-through
+            // fall-through
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+            Q_FALLTHROUGH();
+#endif
         default:
             qCWarning(KCALUTILS_LOG) << "Unknown type" << iter->typeName() << "(" << iter->type() << ")";
             break;
@@ -91,15 +93,13 @@ QString GrantleeKi18nLocalizer::localizeString(const QString &string, const QVar
     return processArguments(str, arguments);
 }
 
-QString GrantleeKi18nLocalizer::localizePluralContextString(const QString &string, const QString &pluralForm,
-        const QString &context, const QVariantList &arguments) const
+QString GrantleeKi18nLocalizer::localizePluralContextString(const QString &string, const QString &pluralForm, const QString &context, const QVariantList &arguments) const
 {
     const KLocalizedString str = kxi18ncp(qPrintable(context), qPrintable(string), qPrintable(pluralForm));
     return processArguments(str, arguments);
 }
 
-QString GrantleeKi18nLocalizer::localizePluralString(const QString &string, const QString &pluralForm,
-        const QVariantList &arguments) const
+QString GrantleeKi18nLocalizer::localizePluralString(const QString &string, const QString &pluralForm, const QVariantList &arguments) const
 {
     const KLocalizedString str = kxi18np(qPrintable(string), qPrintable(pluralForm));
     return processArguments(str, arguments);
